@@ -7,13 +7,13 @@ test <- function(class = c("sf", "sp"), ...) {
 }
 
 test_that("get_layer works with downloadable data", {
-  skip_if_not_installed("bcmaps.rdata")
+  skip_if_not_installed("bcmapsdata")
   skip_on_cran()
   expect_equal(get_layer("test", force = TRUE, ask = FALSE), "test")
 })
 
 test_that("get_big_data works with specific release", {
-  skip_if_not_installed("bcmaps.rdata")
+  skip_if_not_installed("bcmapsdata")
   skip_on_cran()
   expect_equal(get_big_data("test", "sf", "0.1.1", force = TRUE, ask = FALSE), "test")
   expect_equal(test(release = "0.1.1", force = TRUE, ask = FALSE), "test")
@@ -23,40 +23,41 @@ test_that("get_big_data works with specific release", {
 })
 
 test_that("get_big_data works with latest release", {
-  skip_if_not_installed("bcmaps.rdata")
+  skip_if_not_installed("bcmapsdata")
   skip_on_cran()
   expect_equal(get_big_data("test", "sf", "latest", force = TRUE, ask = FALSE), "test")
   expect_equal(test(force = TRUE, ask = FALSE), "test")
 })
 
 test_that("get_big_data fails when file doesn't exist", {
-  skip_if_not_installed("bcmaps.rdata")
+  skip_if_not_installed("bcmapsdata")
   skip_on_cran()
-  expect_error(get_big_data("test", "sf", "0.1.0"), "No assets matching filename test.rds in 0.1.0 release")
+  expect_error(get_big_data("test", "sf", "0.1.0", force = TRUE, ask = FALSE), "No assets matching filename test.rds in 0.1.0 release")
 })
 
 test_that("check_write_to_data_dir works", {
-  skip_if_not_installed("bcmaps.rdata")
+  skip_if_not_installed("bcmapsdata")
   skip_on_cran()
   expect_message(check_write_to_data_dir(data_dir(), ask = FALSE), "Creating directory to hold bcmaps data")
   expect_true(dir.exists(rappdirs::user_data_dir("bcmaps")))
 })
 
 test_that("gh functions work with and without authentication", {
-  skip_if_not_installed("bcmaps.rdata")
+  skip_if_not_installed("bcmapsdata")
+  skip_on_travis()
   skip_on_cran()
   gh_pat <- ""
   if (nzchar(Sys.getenv("GITHUB_PAT"))) {
     expect_is(get_gh_release("latest"), "list")
     temp <- tempfile(fileext = ".rds")
-    download_release_asset("https://api.github.com/repos/bcgov/bcmaps.rdata/releases/assets/5432872", temp)
+    download_release_asset("https://api.github.com/repos/bcgov/bcmapsdata/releases/assets/5432872", temp)
     expect_equal(readRDS(temp), "test")
     gh_pat <- Sys.getenv("GITHUB_PAT")
     Sys.unsetenv("GITHUB_PAT")
   }
   expect_is(get_gh_release("latest"), "list")
   temp <- tempfile(fileext = ".rds")
-  download_release_asset("https://api.github.com/repos/bcgov/bcmaps.rdata/releases/assets/5432872", temp)
+  download_release_asset("https://api.github.com/repos/bcgov/bcmapsdata/releases/assets/5432872", temp)
   expect_equal(readRDS(temp), "test")
   Sys.setenv("GITHUB_PAT" = gh_pat)
 })
